@@ -1,5 +1,5 @@
 
-/* $Id: pkt.h,v 1.5 1997/06/25 22:09:17 pvmsrc Exp $ */
+/* $Id: pkt.h,v 1.6 1999/07/08 19:00:22 kohl Exp $ */
 
 /*
  *         PVM version 3.4:  Parallel Virtual Machine System
@@ -34,11 +34,15 @@
  *
  *	Packet buffers.
  *
-$Log: pkt.h,v $
-Revision 1.5  1997/06/25 22:09:17  pvmsrc
-Markus adds his frigging name to the author list of
-	every file he ever looked at...
-
+ * $Log: pkt.h,v $
+ * Revision 1.6  1999/07/08 19:00:22  kohl
+ * Fixed "Log" keyword placement.
+ * 	- indent with " * " for new CVS.
+ *
+ * Revision 1.5  1997/06/25  22:09:17  pvmsrc
+ * Markus adds his frigging name to the author list of
+ * 	every file he ever looked at...
+ *
  * Revision 1.4  1997/04/24  20:59:42  pvmsrc
  * added pk_rip structure member (used on mpps)
  *
